@@ -1,3 +1,5 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SLTLCV(CTLIN,CTLOUT,LOUT)
 
@@ -32,6 +34,12 @@
             CALL TIMEQ3(JH,JM,JS)
             CALL TIMEC3(CTMP,JH,JM,JS)
             LPARA=.TRUE.
+          ELSE IF (LCHREQ(CST,'PROG')) THEN
+            CALL OSGARG(0,CTMP)
+            LPARA=.TRUE.
+          ELSE IF (LCHREQ(CST,'USER')) THEN
+            CALL OSGENV('USER',CTMP)
+            LPARA=.TRUE.
           ELSE
             LPARA=.FALSE.
           END IF
