@@ -1,3 +1,5 @@
+**-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SWQFNM(CPARA,CFNAME)
 
@@ -27,12 +29,13 @@
 
       IF (      LCHREQ(CPARA,'FONT1')
      +     .OR. LCHREQ(CPARA,'FONT2')
-     +     .OR. LCHREQ(CPARA,'CL2TN')) THEN
+     +     .OR. LCHREQ(CPARA,'CL2TN')
+     +     .OR. LCHREQ(CPARA,'CMAPLIST')) THEN
         CFLIST(1)=CPX(1:LCP)
         NF=1
       ELSE IF ( LCHREQ(CPARA,'CLRMAP')
      +     .OR. LCHREQ(CPARA,'BITMAP')) THEN
-        IF (IWS.EQ.1) THEN
+        IF (IWS.EQ.1 .OR. IWS.EQ.4) THEN
           CFLIST(1)=CPX(1:LCP)//CX11
           CFLIST(2)=CPX(1:LCP)
           CFLIST(3)=CPX(1:LCP)//CPSX
