@@ -65,7 +65,10 @@
       CALL SZSIDX(INDEX)
       CALL SZSTYP(ITYPE)
 
-      DO 30 DA=DAMIN,DAMAX,RSPCE
+*     DO 30 DA=DAMIN,DAMAX,RSPCE
+      NCNT=MAX(INT((DAMAX-DAMIN+RSPCE)/RSPCE),0)
+      DO 30 IDA=1,NCNT
+        DA=DAMIN+RSPCE*(IDA-1)
         XA=-XSIN*DA
         YA=+XCOS*DA
         X1=XA+XCOS*DBMIN
