@@ -1,11 +1,13 @@
 *-----------------------------------------------------------------------
 *     GLCGET / GLCSET / GLCSTX
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE GLCGET(CP,CPARA)
 
       CHARACTER CP*(*),CPARA*(*)
 
-      CHARACTER CX*8,CPVAL*80
+      CHARACTER CX*40,CPVAL*80
 
 
       CALL GLCQID(CP,IDX)
@@ -22,10 +24,19 @@
 *-----------------------------------------------------------------------
       ENTRY GLCSTX(CP,CPARA)
 
-      CX=CP
       CPVAL=CPARA
-      CALL RTCGET('GL:',CX,CPVAL,1)
       CALL GLCQID(CX,IDX)
+
+*     / SHORT NAME /
+
+      CALL GLCQCP(IDX, CX)
+      CALL RTCGET('GL',CX,CPVAL,1)
+
+*     / LONG NAME /
+
+      CALL GLCQCL(IDX, CX)
+      CALL RLCGET(CX,CPVAL,1)
+
       CALL GLCSVL(IDX,CPVAL)
 
       RETURN
